## Xiaomi Flashable Firmware Creator
Create flashable firmware zip from MIUI Recovery ROMs!

[![Crowdin](https://badges.crowdin.net/mi-flashable-firmware-creator/localized.svg)](https://crowdin.com/project/mi-flashable-firmware-creator)

[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.png?v=103)](https://github.com/ellerbrock/open-source-badges/)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)

Xiaomi Flashable Firmware Creator is a tool that generates flashable firmware-update packages from official MIUI ROMS.

It supports creating untouched firmware, non-arb firmware, firmware + vendor flashable zip, and firmware-less ROMs.
[![screenshot](https://raw.githubusercontent.com/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator.py/py/screenshots/1.png)](https://xiaomifirmwareupdater.com/projects/xiaomi-flashable-firmware-creator/)

### Features:
- Easy-to-use interface
- Multilanguage support (more than 25 languages!). Thanks to our community members!

#### Screenshots:
[Here](https://github.com/XiaomiFirmwareUpdater/xiaomi-flashable-firmware-creator.py/tree/py/screenshots)

### GUI Usage:
- Clone this repo using `git clone --recursive`
- Make sure that you have Python3 installed on your device.
- Install the required packages.
```
pip3 install -r requirements.txt
```
- Run the tool.
```
python3 -m xiaomi_flashable_firmware_creator_gui
```
